#!/usr/bin/env python
##################################################
# Gnuradio Python Flow Graph
# Title: File Replay
# Generated: Sat Aug 18 12:27:35 2012
##################################################

from gnuradio import eng_notation
from gnuradio import gr
from gnuradio import window
from gnuradio.eng_option import eng_option
from gnuradio.gr import firdes
from gnuradio.wxgui import fftsink2
from gnuradio.wxgui import waterfallsink2
from grc_gnuradio import wxgui as grc_wxgui
from optparse import OptionParser
import wx

class file_replay(grc_wxgui.top_block_gui):

	def __init__(self, rate=1000000, file_path=""):
		grc_wxgui.top_block_gui.__init__(self, title="File Replay")
		_icon_path = "/usr/share/icons/hicolor/32x32/apps/gnuradio-grc.png"
		self.SetIcon(wx.Icon(_icon_path, wx.BITMAP_TYPE_ANY))

		##################################################
		# Parameters
		##################################################
		self.rate = rate
		self.file_path = file_path

		##################################################
		# Blocks
		##################################################
		self.wxgui_waterfallsink2_0 = waterfallsink2.waterfall_sink_c(
			self.GetWin(),
			baseband_freq=0,
			dynamic_range=100,
			ref_level=0,
			ref_scale=2.0,
			sample_rate=rate,
			fft_size=512,
			fft_rate=15,
			average=False,
			avg_alpha=None,
			title="Waterfall Plot",
		)
		self.Add(self.wxgui_waterfallsink2_0.win)
		self.wxgui_fftsink2_0 = fftsink2.fft_sink_c(
			self.GetWin(),
			baseband_freq=0,
			y_per_div=10,
			y_divs=10,
			ref_level=0,
			ref_scale=2.0,
			sample_rate=rate,
			fft_size=1024,
			fft_rate=15,
			average=True,
			avg_alpha=0.5,
			title="FFT Plot",
			peak_hold=False,
		)
		self.Add(self.wxgui_fftsink2_0.win)
		self.gr_throttle_0 = gr.throttle(gr.sizeof_gr_complex*1, rate)
		self.gr_multiply_const_vxx_0 = gr.multiply_const_vcc((1.0/(2**16/2), ))
		self.gr_interleaved_short_to_complex_0 = gr.interleaved_short_to_complex()
		self.gr_file_source_0 = gr.file_source(gr.sizeof_short*1, file_path, True)

		##################################################
		# Connections
		##################################################
		self.connect((self.gr_file_source_0, 0), (self.gr_interleaved_short_to_complex_0, 0))
		self.connect((self.gr_throttle_0, 0), (self.wxgui_fftsink2_0, 0))
		self.connect((self.gr_throttle_0, 0), (self.wxgui_waterfallsink2_0, 0))
		self.connect((self.gr_interleaved_short_to_complex_0, 0), (self.gr_multiply_const_vxx_0, 0))
		self.connect((self.gr_multiply_const_vxx_0, 0), (self.gr_throttle_0, 0))

	def get_rate(self):
		return self.rate

	def set_rate(self, rate):
		self.rate = rate
		self.wxgui_fftsink2_0.set_sample_rate(self.rate)
		self.wxgui_waterfallsink2_0.set_sample_rate(self.rate)

	def get_file_path(self):
		return self.file_path

	def set_file_path(self, file_path):
		self.file_path = file_path

if __name__ == '__main__':
	parser = OptionParser(option_class=eng_option, usage="%prog: [options]")
	parser.add_option("-r", "--rate", dest="rate", type="eng_float", default=eng_notation.num_to_str(1000000),
		help="Set Rate [default=%default]")
	parser.add_option("-p", "--file-path", dest="file_path", type="string", default="",
		help="Set File Path [default=%default]")
	(options, args) = parser.parse_args()
	tb = file_replay(rate=options.rate, file_path=options.file_path)
	tb.Run(True)

