#!/usr/bin/env python
##################################################
# Gnuradio Python Flow Graph
# Title: Rx File
# Generated: Sat Aug 18 08:59:40 2012
##################################################

from gnuradio import eng_notation
from gnuradio import gr
from gnuradio import uhd
from gnuradio.eng_option import eng_option
from gnuradio.gr import firdes
from optparse import OptionParser

class rx_file(gr.top_block):

	def __init__(self, freq=500e6, gain=25, ant="TX/RX", samp_rate=1000000, file_path=""):
		gr.top_block.__init__(self, "Rx File")

		##################################################
		# Parameters
		##################################################
		self.freq = freq
		self.gain = gain
		self.ant = ant
		self.samp_rate = samp_rate
		self.file_path = file_path

		##################################################
		# Blocks
		##################################################
		self.uhd_usrp_source_0 = uhd.usrp_source(
			device_addr="",
			stream_args=uhd.stream_args(
				cpu_format="sc16",
				channels=range(1),
			),
		)
		self.uhd_usrp_source_0.set_samp_rate(samp_rate)
		self.uhd_usrp_source_0.set_center_freq(freq, 0)
		self.uhd_usrp_source_0.set_gain(gain, 0)
		self.uhd_usrp_source_0.set_antenna(ant, 0)
		self.gr_file_sink_0 = gr.file_sink(gr.sizeof_short*2, file_path)
		self.gr_file_sink_0.set_unbuffered(False)

		##################################################
		# Connections
		##################################################
		self.connect((self.uhd_usrp_source_0, 0), (self.gr_file_sink_0, 0))

	def get_freq(self):
		return self.freq

	def set_freq(self, freq):
		self.freq = freq
		self.uhd_usrp_source_0.set_center_freq(self.freq, 0)

	def get_gain(self):
		return self.gain

	def set_gain(self, gain):
		self.gain = gain
		self.uhd_usrp_source_0.set_gain(self.gain, 0)

	def get_ant(self):
		return self.ant

	def set_ant(self, ant):
		self.ant = ant
		self.uhd_usrp_source_0.set_antenna(self.ant, 0)

	def get_samp_rate(self):
		return self.samp_rate

	def set_samp_rate(self, samp_rate):
		self.samp_rate = samp_rate
		self.uhd_usrp_source_0.set_samp_rate(self.samp_rate)

	def get_file_path(self):
		return self.file_path

	def set_file_path(self, file_path):
		self.file_path = file_path
		self.gr_file_sink_0.open(self.file_path)

if __name__ == '__main__':
	parser = OptionParser(option_class=eng_option, usage="%prog: [options]")
	parser.add_option("-f", "--freq", dest="freq", type="eng_float", default=eng_notation.num_to_str(500e6),
		help="Set Freq [default=%default]")
	parser.add_option("-g", "--gain", dest="gain", type="eng_float", default=eng_notation.num_to_str(25),
		help="Set Gain [default=%default]")
	parser.add_option("-a", "--ant", dest="ant", type="string", default="TX/RX",
		help="Set Ant [default=%default]")
	parser.add_option("-s", "--samp-rate", dest="samp_rate", type="eng_float", default=eng_notation.num_to_str(1000000),
		help="Set Samp Rate [default=%default]")
	parser.add_option("-f", "--file-path", dest="file_path", type="string", default="",
		help="Set File Path [default=%default]")
	(options, args) = parser.parse_args()
	tb = rx_file(freq=options.freq, gain=options.gain, ant=options.ant, samp_rate=options.samp_rate, file_path=options.file_path)
	tb.start()
	raw_input('Press Enter to quit: ')
	tb.stop()

