#!/usr/bin/python

import sys, thread, time
from optparse import OptionParser
from gnuradio.eng_option import eng_option
from gnuradio import eng_notation
from string import split

import rx_file

def main():
	parser = OptionParser(option_class=eng_option, usage="%prog: [options] <schedule file>")
	#parser.add_option("-f", "--freq", dest="freq", type="eng_float", default=eng_notation.num_to_str(500e6), help="Set Freq [default=%default]")
	parser.add_option("-g", "--gain", dest="gain", type="eng_float", default=eng_notation.num_to_str(25), help="Set Gain [default=%default]")
	parser.add_option("-a", "--ant", dest="ant", type="string", default="TX/RX", help="Set Ant [default=%default]")
	parser.add_option("-s", "--samp-rate", dest="samp_rate", type="eng_float", default=eng_notation.num_to_str(1000000), help="Set Samp Rate [default=%default]")
	#parser.add_option("-f", "--file-path", dest="file_path", type="string", default="", help="Set File Path [default=%default]")
	parser.add_option("-x", "--time-multiplier", type="float", default="1.0", help="Time Multiplier [default=%default]")
	parser.add_option("-p", "--progress-step", type="int", default="1", help="Progress Step [default=%default]")
	parser.add_option("-b", "--base-path", type="string", default="", help="Base Path [default=%default]")
	parser.add_option("-c", "--run-count", type="int", default="1", help="Run Count [default=%default]")
	(options, args) = parser.parse_args()
	
	if len(args) == 0:
		print "Requires schedule file"
		return
	
	schedule_file = args[0]
	print "Reading from schedule file:", schedule_file
	f = open(schedule_file, "r")
	lines = f.readlines()
	f.close()
	
	schedule = []
	files = []
	total = 0
	total_samples = 0
	
	for line in lines:
		line = line.strip()
		if len(line) == 0:
			continue
		if line[0] == "#":
			continue
		parts = line.split()
		rate = options.samp_rate
		if len(parts) >= 4:
			rate = float(parts[3]) * 1000000.0
		duration = int(float(parts[0])*options.time_multiplier)
		if duration < 1:
			raise Exception("Invalid duration:", str(float(parts[0])*options.time_multiplier))
		schedule += [{'duration':duration, 'frequency':float(parts[1]) * 1000000.0, 'file':parts[2], 'rate':rate}]
		if parts[2] in files:
			raise Exception("Duplicate files:" + parts[2])
		files += [parts[2]]
		total += duration
		total_samples += (duration * rate * 4)	# 4 bytes per sample
	
	for part in schedule:
		print part
	
	print "Total time: %d seconds (%d mins %d secs)" % (total, int(total*1.0/60.0), (total % 60))
	estimated_size_mb = total_samples*1.0/(1024*1024)
	print "Total space: %.1f MB (%.2f GB)" % (estimated_size_mb, estimated_size_mb/1024.0)
	
	raw_input("Press ENTER to continue...")
	print ""
	
	tb = None
	run_count = 1
	try:
		while True:
			print "Starting run", run_count
			for part in schedule:
				print part
				if part['file'] == "-":
					tb = None
				else:
					file_path = part['file']
					if len(options.base_path) > 0:
						file_path = options.base_path + "/" + file_path
					if options.run_count != 1:
						file_path += "-" + str(run_count)
					print "Recording to", file_path, "at rate", part['rate'], "gain", options.gain, "antenna", options.ant, "frequency", part['frequency']
					tb = rx_file.rx_file(freq=part['frequency'], gain=options.gain, ant=options.ant, samp_rate=part['rate'], file_path=file_path)
					print "Starting..."
					tb.start()
				i = 0
				progress = 0
				while True:
					time.sleep(1.0)
					i += 1
					progress += 1
					if progress == options.progress_step:
						sys.stdout.write(".")
						sys.stdout.flush()
						progress = 0
					if i == part['duration']:
						sys.stdout.write("\n")
						break
				if tb is not None:
					print "Stopping..."
					tb.stop()
					del tb
				print "------------------------------------------------------------"
			if run_count == options.run_count:
				break
			run_count += 1
	except KeyboardInterrupt:
		print "Closing..."
		if tb is not None:
			print "Exiting..."
			tb.stop()
			del tb
	#except Exception, e:
	#

if __name__ == '__main__':
	main()
